@@ -37,7 +37,10 @@ class Customer(Model):
         permission_classes = [CustomerPermissions]
 
     def __str__(self):
-        return self.name or self.urlid
+        try:
+            return '{} ({})'.format(self.name, self.urlid)
+        except:
+            return self.urlid
 
 
 class BusinessProvider(Model):
@@ -45,7 +48,10 @@ class BusinessProvider(Model):
     fee = models.PositiveIntegerField(default='0', null=True, blank=True)
 
     def __str__(self):
-        return self.name or self.urlid
+        try:
+            return '{} ({})'.format(self.name, self.urlid)
+        except:
+            return self.urlid
 
 
 def auto_increment_project_number():
@@ -63,6 +69,11 @@ STATUS_CHOICES = [
 ]
 
 
+project_fields = ["@id", "name", "description", "status", "number", "creationDate", "customer", "captain", "driveID", "businessProvider", "jabberID", "jabberRoom", "members"]
+if 'djangoldp_community' in settings.DJANGOLDP_PACKAGES:
+    project_fields += ['community']
+
+
 class Project(Model):
     name = models.CharField(max_length=255, null=True, blank=True)
     description = models.TextField(null=True, blank=True)
@@ -87,7 +98,10 @@ class Project(Model):
         rdf_type = 'hd:project'
 
     def __str__(self):
-        return self.name or self.urlid
+        try:
+            return '{} {} ({})'.format(self.customer.name, self.name, self.urlid)
+        except:
+            return self.urlid
 
     def get_admins(self):
         return self.members.filter(is_admin=True)
@@ -109,7 +123,10 @@ class Member(Model):
         view_set = ProjectMembersViewset
 
     def __str__(self):
-        return str(self.pk) or self.urlid
+        try:
+            return '{} -> {} ({})'.format(self.project.urlid, self.user.urlid, self.urlid)
+        except:
+            return self.urlid
 
     def save(self, *args, **kwargs):
         if self.user:
